/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.stunner.cm.client.canvas.controls.builder;

import org.junit.Before;
import org.junit.runner.RunWith;
import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.impl.AbstractElementBuilderControl;
import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationMessages;
import org.mockito.Mock;
import org.mockito.runners.MockitoJUnitRunner;
import org.uberfire.mocks.EventSourceMock;

import static org.mockito.Mockito.mock;

@RunWith(MockitoJUnitRunner.class)
public class CaseManagementObserverBuilderControlTest extends BaseCaseManagementBuilderControlTest {

    @Mock
    private EventSourceMock<CanvasSelectionEvent> selectionEvent;

    @Before
    @Override
    public void setup() {
        super.setup();
    }

    @Override
    protected AbstractElementBuilderControl getBuilderControl() {
        return new CaseManagementObserverBuilderControl(clientDefinitionManager,
                                                        clientFactoryServices,
                                                        ruleManager,
                                                        canvasCommandFactory,
                                                        mock(ClientTranslationMessages.class),
                                                        graphBoundsIndexer,
                                                        selectionEvent);
    }
}
